==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-session/lxqt-session_es_UY.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_UY">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="302"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="303"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Bienvenido a LXQt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Bienvenido a LXQt&lt;/b&gt;
&lt;p&gt;
Antes de empezar a usar LXQt puede querer seleccionar el administrador de ventanas:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation type="vanished">Puede cambiar el administrador de ventanas más adelante en cualquier momento usando el Configurador de Sesiones de LXQt.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-session/lxqt-session_es_UY.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_UY">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="309"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="310"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <source>Configuration file path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>Window manager to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Bienvenido a LXQt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Bienvenido a LXQt&lt;/b&gt;
&lt;p&gt;
Antes de empezar a usar LXQt puede querer seleccionar el administrador de ventanas:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation type="vanished">Puede cambiar el administrador de ventanas más adelante en cualquier momento usando el Configurador de Sesiones de LXQt.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
